import sys

from PyQt4.QtGui import QApplication, QDockWidget, QTextBrowser, QSplitter, QTextDocument, QMainWindow
from PyQt4.QtCore import Qt, SIGNAL, QUrl, QVariant
from PyQt4.QtHelp import QHelpEngine

class Help(QMainWindow):
    def __init__(self, mainWindow):
        QMainWindow.__init__(self)

        # create help window
        helpwindow = QDockWidget(self)
        helpwindow.setFloating(False)
        helpwindow.setFeatures(QDockWidget.NoDockWidgetFeatures)

        # create QSplitter
        self.__mainWidget = QSplitter(Qt.Horizontal)

        # create helper and set it up
        self.__helper = QHelpEngine("/path/to/help.qhc", self)
        self.__helper.setupData()

        # Get the content widget and instanciate HelpBrowser (defined below).
        # The __helper.contentWidget() displays the table of content of the help
        self.__content = self.__helper.contentWidget()
        self.__helpBrowser = HelpBrowser(self.__mainWidget, self.__helper)

        # build widget
        self.__mainWidget.insertWidget(0, self.__content)
        self.__mainWidget.insertWidget(1, self.__helpBrowser)
        self.__mainWidget.setStretchFactor(1, 1)
        helpwindow.setWidget(self.__mainWidget)
        self.addDockWidget(Qt.TopDockWidgetArea, helpwindow)

        # connect the TOC to the help browser.
        self.connect(self.__helper.contentWidget(),
                     SIGNAL("linkActivated(const QUrl &)"),
                     self.__helpBrowser.setSource)

class   HelpBrowser(QTextBrowser):
        def __init__(self, parent, help_engine):
           QTextBrowser.__init__(self)
           self.__helpEngine = help_engine

        # call QHelpEngine.fileData() for 'qthelp' resources and use the
        # default implementation for all others url. 'url' param is a QUrl.
        def loadResources(self, type, url):
            if url.scheme() == "qthelp":   
                return QVariant(self.__helpEngine.fileData(url))
            return QTextBrowser.loadResources(type, url)
 
if __name__ == '__main__':
    a = QApplication(sys.argv)
    help = Help(QMainWindow)
    help.show()
    sys.exit(a.exec_())



